@@ -10,7 +10,6 @@ from typing import List, Set, Optional, Generator, Tuple
 
 from zepben.cimbend.cim.iec61970.base.core.base_voltage import BaseVoltage
 from zepben.cimbend.cim.iec61970.base.core.equipment import Equipment
-from zepben.cimbend.exceptions import NoEquipmentException
 
 __all__ = ['ConductingEquipment']
 
@@ -126,7 +125,7 @@ class ConductingEquipment(Equipment):
         return self
 
     def __repr__(self):
-        return (f"{super().__repr__()}, num_cores={self.num_cores} in_service={self.in_service}, "
+        return (f"{super(ConductingEquipment, self).__repr__()}, num_cores={self.num_cores} in_service={self.in_service}, "
                 f"normally_in_service={self.normally_in_service}, location={self.location}"
                 )
 
@@ -157,12 +156,6 @@ class ConductingEquipment(Equipment):
                 lambda: f"Terminal {terminal} references another piece of conducting equipment {terminal.conducting_equipment}, expected {str(self)}.")
         return False
 
-    def get_terminal_for_node(self, node):
-        for t in self._terminals:
-            if t.connectivity_node.mrid == node.mrid:
-                return t
-        raise NoEquipmentException(f"Equipment {self.mrid} is not connected to node {node.mrid}")
-
     def get_connected_equipment(self, exclude: Set = None):
         """
         Get all `ConductingEquipment` connected to this piece of equipment. An `Equipment` is connected if it has
